@@ -7,6 +7,7 @@ T = TypeVar("T")
 
 
 class Config(SaveModelMixin, DeleteModelMixin, BaseModel):
+
     def __init__(
         self,
         url=None,
@@ -37,13 +38,15 @@ class Config(SaveModelMixin, DeleteModelMixin, BaseModel):
         self.updated_by = updated_by
         self.updated_at = updated_at
 
-        self._read_only = [
-            "url",
-            "id",
-            "version",
-            "update_by",
-            "update_at",
-        ]
-
+    _read_only = [
+        "url",
+        "id",
+        "version",
+        "updated_by",
+        "updated_at",
+        "created_at",
+    ]
+    
+    @operation
     def duplicate(self: T, name=None, title=None) -> T:
-        return self.api_resource.duplicate(self, name=name, title=title)
+        pass
