@@ -1,8 +1,9 @@
 from ..base import *
+from ..models import *
 from .mixins import *
 
 
-class Execution(SaveModelMixin, BaseModel):
+class Execution(ParentMixin, SaveModelMixin, BaseModel):
     def __init__(
         self,
         url=None,
@@ -48,11 +49,32 @@ class Execution(SaveModelMixin, BaseModel):
         self.result = result
         self.user = user
 
-        self._read_only = [
-            "url",
-            "id",
-            "runtime",
-            "task",
-            "parent_task_execution",
-            "parent_execution",
-        ]
+    _read_only = [
+        "url",
+        "id",
+        "runtime",
+        "task",
+        "parent_task_execution",
+        "parent_execution",
+    ]
+
+    _submodels = [TaskExecution]
+
+    def tasks(self, identifier=None, **kwargs) -> Union[TaskExecution, List[TaskExecution]]:
+        return self._get(TaskExecution, identifier, **kwargs)
+
+    @operation
+    def cancel(self) -> None:
+        pass
+
+    @operation
+    def pause(self) -> None:
+        pass
+
+    @operation
+    def resume(self) -> None:
+        pass
+
+    @operation
+    def log(self) -> str:
+        pass
