@@ -24,11 +24,9 @@ class NjinnGroup(ParentMixin, SaveModelMixin, DeleteModelMixin, BaseModel):
         self.group_members = group_members
         self.created_at = created_at
 
-        self._read_only = ["id", "created_at"]
+    _read_only = ["id", "created_at"]
 
-    @property
-    def _submodels(self):
-        return [GroupMember]
+    _submodels = [GroupMember]
 
     def members(
         self, identifier=None, **kwargs
