@@ -14,10 +14,8 @@ class ConfigResource(
     def __init__(self, client: NjinnClient):
         super().__init__("api/v1/configs", Config, client)
 
-    def duplicate(self, obj: Config, **kwargs) -> Config:
-        body = ResourceUtil.exclude_none(kwargs)
-        response = self.client.post(f"{self.path}/duplicate", body)
-        return self.construct(response)
+    def duplicate(self, **kwargs) -> Config:
+        return self.operation("duplicate", Config).post(**kwargs)
 
 
 Mapping.register(Config, ConfigResource)
