@@ -19,10 +19,10 @@ class GetResourceMixin(BaseResource):
 class SaveResourceMixin(BaseResource):
     def save(self, obj: BaseModel, fields: List = None):
         if fields:
-            body = ResourceUtil.extract_body(obj, fields)
+            body = ResourceUtil.to_json(obj, fields=fields)
             response = self.client.patch(f"{self.path}", body)
         else:
-            body = ResourceUtil.extract_body(obj)
+            body = ResourceUtil.to_json(obj)
             response = self.client.put(f"{self.path}", body)
 
         return self.construct(response)
@@ -30,9 +30,7 @@ class SaveResourceMixin(BaseResource):
 
 class CreateResourceMixin(BaseResource):
     def create(self, obj: BaseModel):
-        body = ResourceUtil.extract_body(obj)
-        body = ResourceUtil.exclude_none(body)
-
+        body = ResourceUtil.to_json(obj, exclude_none=True)
         response = self.client.post(f"{self.path}", body)
         return self.construct(response)
 
